@@ -159,7 +159,7 @@ int 	numkeys;
 
 	startup();
 
-	if (Dsp==(Display *)NULL)
+	if (Dsp==NULL)
 		return;
 
 	if (!Setup_Extension_DeviceInfo(KeyMask))
