@@ -233,7 +233,7 @@ Status		status;
 XVisualInfo	*vp;
 int		nwins = 7;
 Window		pwins[7];
-Window		*rwins = (Window *) NULL;
+Window		*rwins = NULL;
 Window		*wp;
 int		rcnt = 0;
 int		i;
@@ -314,7 +314,7 @@ int 	pass = 0, fail = 0;
 	pfcount(pass, fail);
 }
 
-/* Including from file Mdefcode.tmc.28365 */
+/* Including from file Mdefcode.tmc.9711 */
 static void t002(){
 
 int 	pass = 0, fail = 0;
@@ -337,7 +337,7 @@ int 	pass = 0, fail = 0;
 	pfcount(pass, fail);
 }
 
-/* End of included file Mdefcode.tmc.28365 */
+/* End of included file Mdefcode.tmc.9711 */
 
 static void t003(){
 
