@@ -305,7 +305,7 @@ unsigned long	nitems;
 unsigned long	leftover;
 int		nwins = 7;
 Window		pwins[7];
-Window		*rwins = (Window *) NULL;
+Window		*rwins = NULL;
 Window		*wp;
 int		i;
 int 	pass = 0, fail = 0;
@@ -421,7 +421,7 @@ int 	pass = 0, fail = 0;
 	pfcount(pass, fail);
 }
 
-/* Including from file Mdefcode.tmc.28399 */
+/* Including from file Mdefcode.tmc.9745 */
 static void t002(){
 
 int 	pass = 0, fail = 0;
@@ -442,7 +442,7 @@ int 	pass = 0, fail = 0;
 	pfcount(pass, fail);
 }
 
-/* End of included file Mdefcode.tmc.28399 */
+/* End of included file Mdefcode.tmc.9745 */
 
 /* Including from file error/EAll.mc */
 /* End of included file error/EAll.mc */
