@@ -303,7 +303,7 @@ int		actual_format;
 Atom		actual_type;
 int		nats = 5;
 Atom		xa_wm_protocols;
-Atom		prots[5], *rprots = (Atom *) NULL;
+Atom		prots[5], *rprots = NULL;
 Atom		at, *atp;
 int		i;
 int 	pass = 0, fail = 0;
@@ -419,7 +419,7 @@ int 	pass = 0, fail = 0;
 	pfcount(pass, fail);
 }
 
-/* Including from file Mdefcode.tmc.28412 */
+/* Including from file Mdefcode.tmc.9754 */
 static void t002(){
 
 int 	pass = 0, fail = 0;
@@ -440,7 +440,7 @@ int 	pass = 0, fail = 0;
 	pfcount(pass, fail);
 }
 
-/* End of included file Mdefcode.tmc.28412 */
+/* End of included file Mdefcode.tmc.9754 */
 
 /* Including from file error/EAll.mc */
 /* End of included file error/EAll.mc */
