@@ -468,6 +468,13 @@ int 	pass = 0, fail = 0;
 
 	xwbf_start();
 	setargs();
+/* Writing won't fail even if the permissions say it should if we're root. */
+	if(geteuid() == 0) {
+	    report("File permissions cannot be tested as root.");
+	    UNTESTED;
+	    return;
+	}
+
 /* Create a suitable bitmap. */
 /* Create an unwritable directory. */
 	if(mkdir(XWBF_DIR, XWBF_MODE)) {
@@ -509,7 +516,7 @@ int 	pass = 0, fail = 0;
 	pfcount(pass, fail);
 }
 
-/* Including from file Mdefcode.tmc.28828 */
+/* Including from file Mdefcode.tmc.10164 */
 static void t004(){
 
 int 	pass = 0, fail = 0;
@@ -530,7 +537,7 @@ int 	pass = 0, fail = 0;
 	pfcount(pass, fail);
 }
 
-/* End of included file Mdefcode.tmc.28828 */
+/* End of included file Mdefcode.tmc.10164 */
 
 static void t005(){
 
