@@ -254,8 +254,8 @@ Pixmap nondepth1pixmap( Display *disp,  Drawable d);
 void setfuncpixel(Display *disp, Drawable drw, int  *xp, int  *yp);
 void regid(Display *disp, union regtypes *id, int  type);
 void freereg(void);
-int regenable(void);
-int regdisable(void);
+void regenable(void);
+void regdisable(void);
 void openfonts(Font fonts[], int  nfonts);
 int checkfsp(XFontStruct *fsp, XFontStruct *good, char *str);
 void txtextents(XFontStruct *fsp, unsigned char *str, int  n, int  *dir, int  *ascent, int  *descent, XCharStruct *overall);
@@ -321,8 +321,8 @@ void settimeout(int  to);
 unsigned long cleartimeout(void);
 Region makeregion(void);
 int samehost(XHostAddress *h1, XHostAddress *h2);
-int pfcount(int  pass, int  fail);
-int rptcounts(void);
+void pfcount(int  pass, int  fail);
+void rptcounts(void);
 Status SimulateKeyPressEvent(Display *dpy, KeyCode keycode);
 Status SimulateKeyReleaseEvent(Display *dpy, KeyCode keycode);
 Status SimulateButtonPressEvent(Display  *dpy, unsigned int button);
@@ -341,10 +341,10 @@ void relbuttons(void);
 void relkeys(void);
 void relalldev(void);
 unsigned int wantmods(Display *disp, int  want);
-int modpress(Display *disp, unsigned int  mask);
-int modrel(Display *disp, unsigned int  mask);
+void modpress(Display *disp, unsigned int  mask);
+void modrel(Display *disp, unsigned int  mask);
 int ismodkey(unsigned int  mask, int kc);
-int restoredevstate(void);
+void restoredevstate(void);
 int noext(int  needbutton);
 int nbuttons(void);
 int getkeycode(Display *display);
